@@ -2,7 +2,6 @@ package statusbar
 
 import (
 	"github.com/charmbracelet/lipgloss"
-	jqp_styles "github.com/noahgorstein/jqp/tui/styles"
 )
 
 type styles struct {
@@ -14,8 +13,8 @@ type styles struct {
 func defaultStyles() (s styles) {
 
 	s.containerStyle = lipgloss.NewStyle().PaddingLeft(1)
-	s.errorMessageStyle = lipgloss.NewStyle().Foreground(jqp_styles.RED)
-	s.successMessageStyle = lipgloss.NewStyle().Foreground(jqp_styles.GREEN)
+	s.errorMessageStyle = lipgloss.NewStyle()
+	s.successMessageStyle = lipgloss.NewStyle()
 
 	return s
 
